import smtplib
import socket

from email.mime.text import MIMEText


class PostSend:
    def __init__(self, e_mail: str, smtp: str, pwd: str, mess: str, port=465):
        """
        Инициализируются указанные ниже параметры. Отправка сообщений
        с трех почтовых серверов: mail.ru, yandex.ru, gmail.com.

        :param e_mail: Адрес отправителя.
        :param smtp: smtp-сервер электронной почты.
        :param pwd: Пароль приложения для отправки почты.
        :param mess: Сообщение для отправки.
        :param port: Порт smtp-сервера. Необязательный параметр. Выставлен по умолчанию.
        """
        self.e_mail = e_mail
        self.smtp = smtp
        self.pwd = pwd
        self.mess = mess
        self.port = port

    def mail_send(self, send_to: str, subj: str):
        """
        Функция принимает адрес получателя и тему письма.
        Проверят, не является ли почта отправителя yandex.ru,
        так как там немного другие правила авторизации.
        Сообщение или шаблон переводятся в MIMEText, чтобы
        избежать проблемы с отправкой кириллицы. Подставляются
        поля кому, от кого, тема и отправляется по адресу.

        :param send_to: Адрес получателя.
        :param subj: Тема сообщения.
        :return: Сообщение об отправке или ошибке.
        """
        try:
            s = smtplib.SMTP_SSL(self.smtp, self.port)
        except socket.gaierror:
            return 'Ошибка соединения'
        if self.e_mail.split("@")[-1] in ['yandex.ru', 'yandex.com', 'yandex.by', 'yandex.kz', 'ya.ru']:
            login = self.e_mail.split("@")[0]
        else:
            login = self.e_mail
        s.login(login, self.pwd)
        mess = MIMEText(self.mess, 'html')
        mess['From'] = self.e_mail
        mess['To'] = send_to
        mess['Subject'] = subj
        s.sendmail(self.e_mail, send_to, mess.as_string())
        s.quit()
        return 'Письмо успешно отправлено'

