import json
import os.path

from post_send_new import PostSend

dir_set = os.path.join(os.getcwd(), 'set')


def make_addr():
    """
    Запрашивает параметры почты у пользователя. Адрес, пароль приложения.
    Сохраняет полученные значения в файл json.
    Запрашивает у пользователя согласие на использование созданного
    адреса в текущем скрипте. Если да, возвращает адрес. Если нет,
    возвращается в стартовую функцию.

    :return: Возвращает адрес отправителя
    """
    set_dict = dict()

    e_mail = input('\nВведите адрес электронной почты: ')
    pass_post = input('Введите пароль доступа приложения: ')
    smtp = f'smtp.{e_mail.split("@")[-1]}'
    port = 465
    if not os.path.exists(dir_set):
        os.mkdir(dir_set)
    set_dict.update({e_mail: {"smtp": smtp, "port": port, "pwd": pass_post}})
    with open(os.path.join(dir_set, f'{e_mail}.json'), 'w', encoding='utf-8') as post:
        json.dump(set_dict, post, indent=4, ensure_ascii=False)
    print('\nКонфигурация сохранена!')
    ch = input('Желаете использовать созданный адрес в скрипте? Y/N >>> ')
    if ch.lower() == "y":
        return e_mail
    else:
        new = input('\nЖелаете добавить еще один адрес? Y/N >>> ')
        if new.lower() == "y":
            make_addr()
        else:
            start_set()
            return


def start_set():
    """
    Сканируется директория на наличие файлов конфигурации.
    Создается список файлов, который выводится в терминал.
    Если файлов не обнаружено, выполняется запрос на создание файла
    конфигурации.
    Запрашивается у пользователя адрес для использования в скрипте.

    :return: Возвращает адрес электронной почты из файла.
    """
    if os.path.exists(dir_set):
        list_post = [x.split(".json")[0] for x in os.listdir(dir_set) if x.endswith(".json")]
        if len(list_post) > 0:
            print('\nОбнаружены следующие доступные адреса:')
            for addr in list_post:
                print(f'   - Адрес: {addr}')
            ch = input('\nВведите адрес для использования в скрипте\n   или "new", для создания нового адреса.\n   '
                       '>>> ')
            if ch.lower() == 'new':
                make_addr()
            else:
                return ch
        else:
            print('Адреса не обнаружены!')
            ch = input('Желаете создать адрес? Y/N >>> ')
            if ch.lower() == "y":
                make_addr()
                return
            else:
                main()
                return
    else:
        print('Адреса не обнаружены!')
        ch = input('Желаете создать адрес? Y/N >>> ')
        if ch.lower() == "y":
            make_addr()
        else:
            main()
            return


def open_set(address):
    """
    Считывают параметры из файла конфигурации и присваиваются в переменные.
    Имя файла конфигурации передается на вход функции.

    :param address: Адрес электронной почты для считывания параметров из файла.
    :return: Возвращает smtp-сервер, порт сервера, пароль приложения.
    """
    try:
        with open(os.path.join(dir_set, f'{address}.json'), 'r', encoding='utf-8') as file:
            read = dict(json.load(file))
            smtp = read[address]['smtp']
            port = read[address]['port']
            pwd = read[address]['pwd']
        return smtp, pwd, port
    except json.decoder.JSONDecodeError:
        print('Указанный файл не содержит настроек')
        start_set()
        return
    except FileNotFoundError:
        print('Файл не найден')
        start_set()
        return


def template(mess: str):
    """
    Шаблон простого сообщения для отправки.

    :param mess: Текстовое сообщение набранное пользователем.
    :return: Возвращает шаблон с сообщением в теле.
    """
    templ = f"""
    <!DOCTYPE html>
    <html lang="ru">
        <head>
            <meta charset="UTF-8">
            <meta http-equip="X-UA-Compatible" content="IE-edge">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Сообщение</title>
        </head>
        <body>
            <span>{mess}</span>
    </body>
    </html>
    """
    return templ


def main():
    """
    Запрос параметров у пользователя. Ввод темы сообщения.
    Адресата. ВЫбор для отправки: простого сообщения, шаблона подготовленного
    заранее. Если пользователь выбирает простое сообщение, запрашивается его текст.
    Если шаблон, путь к заранее приготовленному шаблону.
    Выполняет проверка, если шаблон по указанному пути.
    Считываются параметры выбранной почты. Создается экземпляр
    класса для отправки сообщения. Передаются параметры: адрес отправителя,
    smtp-сервер, пароль приложения, шаблон сообщения, порт - необязательный параметр.
    ВЫзывается метод отправки сообщения. Выводится в терминал возврат из метода.

    :return: Выход из функции
    """
    address = start_set()
    subj = input('\nТема сообщения: ')
    send_to = input('Адресат сообщения: ')
    ch = input('\nОтправить:\n   [1] Текст сообщения\n   [2] Шаблон\n   >>> ')

    if ch == "1":
        mess = input("\nВведите сообщение для отправки: ")
        temp = template(mess)
    elif ch == "2":
        temp_local = input('\nВведите путь к html-шаблону: ')
        if not os.path.exists(temp_local):
            print('\nШаблона по указанному пути нет.')
            main()
            return
        with open(temp_local, 'r', encoding='utf-8') as file:
            temp = file.read()
    else:
        print('Вы не сделали выбор')
        main()
        return

    params = open_set(address)

    post = PostSend(address, params[0], params[1], temp, params[2])
    print(f'\n{post.mail_send(send_to, subj)}')


if __name__ == "__main__":
    main()
